@@ -29,8 +29,13 @@
 class Q_DECL_HIDDEN LdapDN::LdapDNPrivate
 {
 public:
-    LdapDNPrivate() : m_dn() {}
-    ~LdapDNPrivate() {}
+    LdapDNPrivate() : m_dn()
+    {
+    }
+
+    ~LdapDNPrivate()
+    {
+    }
 
     bool isValidRDNString(const QString &rdn) const;
     QStringList splitOnNonEscapedChar(const QString &rdn, QChar ch) const;
@@ -44,8 +49,9 @@ bool LdapDN::LdapDNPrivate::isValidRDNString(const QString &rdn) const
 
     // If it is a muli-valued rdn, split it into its constituent parts
     QStringList rdnParts = splitOnNonEscapedChar(rdn, QLatin1Char('+'));
-    if (rdnParts.size() > 1) {
-        for (int i = 0; i < rdnParts.size(); i++) {
+    const int numberOfParts(rdnParts.size());
+    if (numberOfParts > 1) {
+        for (int i = 0; i < numberOfParts; i++) {
             if (!isValidRDNString(rdnParts.at(i))) {
                 return false;
             }
@@ -54,7 +60,7 @@ bool LdapDN::LdapDNPrivate::isValidRDNString(const QString &rdn) const
     }
 
     // Split the rdn into the attribute name and value parts
-    const QStringList components = rdn.split(QLatin1Char('='));
+    const QVector<QStringRef> components = rdn.splitRef(QLatin1Char('='));
 
     // We should have exactly two parts
     if (components.size() != 2) {
@@ -95,7 +101,6 @@ QStringList LdapDN::LdapDNPrivate::splitOnNonEscapedChar(const QString &str, QCh
 LdapDN::LdapDN()
     : d(new LdapDNPrivate)
 {
-
 }
 
 LdapDN::LdapDN(const QString &dn)
@@ -168,10 +173,11 @@ QString LdapDN::rdnString() const
 QString LdapDN::rdnString(int depth) const
 {
     QStringList rdns = d->splitOnNonEscapedChar(d->m_dn, QLatin1Char(','));
-    if (depth >= rdns.size()) {
+    const int numberOfRdns(rdns.size());
+    if (depth >= numberOfRdns) {
         return QString();
     }
-    return rdns.at(rdns.size() - 1 - depth);
+    return rdns.at(numberOfRdns - 1 - depth);
 }
 
 bool LdapDN::isValid() const
@@ -197,12 +203,12 @@ int LdapDN::depth() const
     return rdns.size();
 }
 
-bool LdapDN::operator == (const LdapDN &rhs) const
+bool LdapDN::operator ==(const LdapDN &rhs) const
 {
     return d->m_dn == rhs.d->m_dn;
 }
 
-bool LdapDN::operator != (const LdapDN &rhs) const
+bool LdapDN::operator !=(const LdapDN &rhs) const
 {
     return d->m_dn != rhs.d->m_dn;
 }
